##  Defining the Scope of a Survey
Define the scope of the survey by selecting the relevant fact sheets that you want to include in the survey. To do so, follow these steps:
  1. Click on Open Fact Sheet Filters
  2. Select the needed fact sheets or apply filters to narrow down the scope
  3. Click Use Fact Sheet Filter to include the filtered list, or click Use Selected Fact Sheets to select only the needed fact sheets from the list.
  4. The selected fact sheets are now displayed as a list. If you need to modify the list of selected fact sheets, you can do so by clicking on change at the top.
  5. Click Next to finish.


You can also make the survey's scope dynamic or static using the toggle at the top of the list.
  * Dynamic: Fact sheets meeting the specified filters will be included in the survey as long as the survey is in a running status. Conversely, any fact sheets that do not meet the applied filters will be excluded. For example, if a lifecycle filter is applied, new fact sheets are added or removed from the survey as their lifecycle changes The survey will also continuously monitor changes in fact sheet subscriptions. If a subscription is added to a fact sheet associated with an ongoing survey, the subscriber will be invited to participate.
  * Static: The survey scope is restricted to the fact sheets shown in the list. No new fact sheets will be added/ removed from the survey, regardless of any future changes to fact sheets or subscriptions.
